==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkShaderProgram.java <==
// java wrapper for vtkShaderProgram object
//

package vtk;
import vtk.*;

public class vtkShaderProgram extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetVertexShader_2();
  public vtkShader GetVertexShader() {
    long temp = GetVertexShader_2();

    if (temp == 0) return null;
    return (vtkShader)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetVertexShader_3(vtkShader id0);
  public void SetVertexShader(vtkShader id0)
    { SetVertexShader_3(id0); }

  private native long GetFragmentShader_4();
  public vtkShader GetFragmentShader() {
    long temp = GetFragmentShader_4();

    if (temp == 0) return null;
    return (vtkShader)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFragmentShader_5(vtkShader id0);
  public void SetFragmentShader(vtkShader id0)
    { SetFragmentShader_5(id0); }

  private native long GetGeometryShader_6();
  public vtkShader GetGeometryShader() {
    long temp = GetGeometryShader_6();

    if (temp == 0) return null;
    return (vtkShader)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGeometryShader_7(vtkShader id0);
  public void SetGeometryShader(vtkShader id0)
    { SetGeometryShader_7(id0); }

  private native boolean GetCompiled_8();
  public boolean GetCompiled()
    { return GetCompiled_8(); }

  private native void SetCompiled_9(boolean id0);
  public void SetCompiled(boolean id0)
    { SetCompiled_9(id0); }

  private native void CompiledOn_10();
  public void CompiledOn()
    { CompiledOn_10(); }

  private native void CompiledOff_11();
  public void CompiledOff()
    { CompiledOff_11(); }

  private native String GetMD5Hash_12();
  public String GetMD5Hash()
    { return GetMD5Hash_12(); }

  private native void SetMD5Hash_13(String id0);
  public void SetMD5Hash(String id0)
    { SetMD5Hash_13(id0); }

  private native boolean isBound_14();
  public boolean isBound()
    { return isBound_14(); }

  private native void ReleaseGraphicsResources_15(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_15(id0); }

  private native int GetHandle_16();
  public int GetHandle()
    { return GetHandle_16(); }

  private native String GetError_17();
  public String GetError()
    { return GetError_17(); }

  private native boolean EnableAttributeArray_18(String id0);
  public boolean EnableAttributeArray(String id0)
    { return EnableAttributeArray_18(id0); }

  private native boolean DisableAttributeArray_19(String id0);
  public boolean DisableAttributeArray(String id0)
    { return DisableAttributeArray_19(id0); }

  private native boolean SetUniformi_20(String id0,int id1);
  public boolean SetUniformi(String id0,int id1)
    { return SetUniformi_20(id0,id1); }

  private native boolean SetUniformf_21(String id0,double id1);
  public boolean SetUniformf(String id0,double id1)
    { return SetUniformf_21(id0,id1); }

  private native boolean SetUniform2i_22(String id0,int id1[]);
  public boolean SetUniform2i(String id0,int id1[])
    { return SetUniform2i_22(id0,id1); }

  private native boolean SetUniform2f_23(String id0,double id1[]);
  public boolean SetUniform2f(String id0,double id1[])
    { return SetUniform2f_23(id0,id1); }

  private native boolean SetUniform3f_24(String id0,double id1[]);
  public boolean SetUniform3f(String id0,double id1[])
    { return SetUniform3f_24(id0,id1); }

  private native boolean SetUniform4f_25(String id0,double id1[]);
  public boolean SetUniform4f(String id0,double id1[])
    { return SetUniform4f_25(id0,id1); }

  private native boolean SetUniformMatrix_26(String id0,vtkMatrix3x3 id1);
  public boolean SetUniformMatrix(String id0,vtkMatrix3x3 id1)
    { return SetUniformMatrix_26(id0,id1); }

  private native boolean SetUniformMatrix_27(String id0,vtkMatrix4x4 id1);
  public boolean SetUniformMatrix(String id0,vtkMatrix4x4 id1)
    { return SetUniformMatrix_27(id0,id1); }

  private native void SetNumberOfOutputs_28(int id0);
  public void SetNumberOfOutputs(int id0)
    { SetNumberOfOutputs_28(id0); }

  private native boolean Substitute_29(String id0,String id1,String id2,boolean id3);
  public boolean Substitute(String id0,String id1,String id2,boolean id3)
    { return Substitute_29(id0,id1,id2,id3); }

  private native boolean IsUniformUsed_30(String id0);
  public boolean IsUniformUsed(String id0)
    { return IsUniformUsed_30(id0); }

  private native boolean IsAttributeUsed_31(String id0);
  public boolean IsAttributeUsed(String id0)
    { return IsAttributeUsed_31(id0); }

  private native void SetFileNamePrefixForDebugging_32(String id0);
  public void SetFileNamePrefixForDebugging(String id0)
    { SetFileNamePrefixForDebugging_32(id0); }

  private native String GetFileNamePrefixForDebugging_33();
  public String GetFileNamePrefixForDebugging()
    { return GetFileNamePrefixForDebugging_33(); }

  public vtkShaderProgram() { super(); }

  public vtkShaderProgram(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-3-aarch64.pkg.tar.xz: vtk/vtkShaderProgram.java <==
// java wrapper for vtkShaderProgram object
//

package vtk;
import vtk.*;

public class vtkShaderProgram extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetVertexShader_2();
  public vtkShader GetVertexShader() {
    long temp = GetVertexShader_2();

    if (temp == 0) return null;
    return (vtkShader)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetVertexShader_3(vtkShader id0);
  public void SetVertexShader(vtkShader id0)
    { SetVertexShader_3(id0); }

  private native long GetFragmentShader_4();
  public vtkShader GetFragmentShader() {
    long temp = GetFragmentShader_4();

    if (temp == 0) return null;
    return (vtkShader)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFragmentShader_5(vtkShader id0);
  public void SetFragmentShader(vtkShader id0)
    { SetFragmentShader_5(id0); }

  private native long GetGeometryShader_6();
  public vtkShader GetGeometryShader() {
    long temp = GetGeometryShader_6();

    if (temp == 0) return null;
    return (vtkShader)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGeometryShader_7(vtkShader id0);
  public void SetGeometryShader(vtkShader id0)
    { SetGeometryShader_7(id0); }

  private native boolean GetCompiled_8();
  public boolean GetCompiled()
    { return GetCompiled_8(); }

  private native void SetCompiled_9(boolean id0);
  public void SetCompiled(boolean id0)
    { SetCompiled_9(id0); }

  private native void CompiledOn_10();
  public void CompiledOn()
    { CompiledOn_10(); }

  private native void CompiledOff_11();
  public void CompiledOff()
    { CompiledOff_11(); }

  private native String GetMD5Hash_12();
  public String GetMD5Hash()
    { return GetMD5Hash_12(); }

  private native void SetMD5Hash_13(String id0);
  public void SetMD5Hash(String id0)
    { SetMD5Hash_13(id0); }

  private native boolean isBound_14();
  public boolean isBound()
    { return isBound_14(); }

  private native void ReleaseGraphicsResources_15(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_15(id0); }

  private native int GetHandle_16();
  public int GetHandle()
    { return GetHandle_16(); }

  private native String GetError_17();
  public String GetError()
    { return GetError_17(); }

  private native boolean EnableAttributeArray_18(String id0);
  public boolean EnableAttributeArray(String id0)
    { return EnableAttributeArray_18(id0); }

  private native boolean DisableAttributeArray_19(String id0);
  public boolean DisableAttributeArray(String id0)
    { return DisableAttributeArray_19(id0); }

  private native boolean SetUniformi_20(String id0,int id1);
  public boolean SetUniformi(String id0,int id1)
    { return SetUniformi_20(id0,id1); }

  private native boolean SetUniformf_21(String id0,double id1);
  public boolean SetUniformf(String id0,double id1)
    { return SetUniformf_21(id0,id1); }

  private native boolean SetUniform2i_22(String id0,int id1[]);
  public boolean SetUniform2i(String id0,int id1[])
    { return SetUniform2i_22(id0,id1); }

  private native boolean SetUniform2f_23(String id0,double id1[]);
  public boolean SetUniform2f(String id0,double id1[])
    { return SetUniform2f_23(id0,id1); }

  private native boolean SetUniform3f_24(String id0,double id1[]);
  public boolean SetUniform3f(String id0,double id1[])
    { return SetUniform3f_24(id0,id1); }

  private native boolean SetUniform4f_25(String id0,double id1[]);
  public boolean SetUniform4f(String id0,double id1[])
    { return SetUniform4f_25(id0,id1); }

  private native boolean SetUniformMatrix_26(String id0,vtkMatrix3x3 id1);
  public boolean SetUniformMatrix(String id0,vtkMatrix3x3 id1)
    { return SetUniformMatrix_26(id0,id1); }

  private native boolean SetUniformMatrix_27(String id0,vtkMatrix4x4 id1);
  public boolean SetUniformMatrix(String id0,vtkMatrix4x4 id1)
    { return SetUniformMatrix_27(id0,id1); }

  private native void SetNumberOfOutputs_28(int id0);
  public void SetNumberOfOutputs(int id0)
    { SetNumberOfOutputs_28(id0); }

  private native boolean Substitute_29(String id0,String id1,String id2,boolean id3);
  public boolean Substitute(String id0,String id1,String id2,boolean id3)
    { return Substitute_29(id0,id1,id2,id3); }

  private native boolean Substitute_30(vtkShader id0,String id1,String id2,boolean id3);
  public boolean Substitute(vtkShader id0,String id1,String id2,boolean id3)
    { return Substitute_30(id0,id1,id2,id3); }

  private native boolean IsUniformUsed_31(String id0);
  public boolean IsUniformUsed(String id0)
    { return IsUniformUsed_31(id0); }

  private native boolean IsAttributeUsed_32(String id0);
  public boolean IsAttributeUsed(String id0)
    { return IsAttributeUsed_32(id0); }

  private native void SetFileNamePrefixForDebugging_33(String id0);
  public void SetFileNamePrefixForDebugging(String id0)
    { SetFileNamePrefixForDebugging_33(id0); }

  private native String GetFileNamePrefixForDebugging_34();
  public String GetFileNamePrefixForDebugging()
    { return GetFileNamePrefixForDebugging_34(); }

  public vtkShaderProgram() { super(); }

  public vtkShaderProgram(long id) { super(id); }
  public native long   VTKInit();

}
